codex - VSCode Extension Manager
================================

Installation
------------

.. code:: shell

    pipsi install git+https://github.com/cauebs/codex#egg=codex

Usage
-----

.. code:: shell

    codex install <extension-id>...
    codex uninstall <extension-id>...
    codex update [<extension-id>...]
    codex list [--show-versions]
    codex (-h | --help)
